@@ -1,33 +1,32 @@
-from __future__ import absolute_import, unicode_literals
+from pathlib import Path
 
 from virtualenv.seed.wheels.util import Wheel
-from virtualenv.util.path import Path
 
 BUNDLE_FOLDER = Path(__file__).absolute().parent
 BUNDLE_SUPPORT = {
     "3.11": {
-        "pip": "pip-22.0.4-py3-none-any.whl",
-        "setuptools": "setuptools-60.10.0-py3-none-any.whl",
+        "pip": "pip-22.2-py3-none-any.whl",
+        "setuptools": "setuptools-63.2.0-py3-none-any.whl",
         "wheel": "wheel-0.37.1-py2.py3-none-any.whl",
     },
     "3.10": {
-        "pip": "pip-22.0.4-py3-none-any.whl",
-        "setuptools": "setuptools-60.10.0-py3-none-any.whl",
+        "pip": "pip-22.2-py3-none-any.whl",
+        "setuptools": "setuptools-63.2.0-py3-none-any.whl",
         "wheel": "wheel-0.37.1-py2.py3-none-any.whl",
     },
     "3.9": {
-        "pip": "pip-22.0.4-py3-none-any.whl",
-        "setuptools": "setuptools-60.10.0-py3-none-any.whl",
+        "pip": "pip-22.2-py3-none-any.whl",
+        "setuptools": "setuptools-63.2.0-py3-none-any.whl",
         "wheel": "wheel-0.37.1-py2.py3-none-any.whl",
     },
     "3.8": {
-        "pip": "pip-22.0.4-py3-none-any.whl",
-        "setuptools": "setuptools-60.10.0-py3-none-any.whl",
+        "pip": "pip-22.2-py3-none-any.whl",
+        "setuptools": "setuptools-63.2.0-py3-none-any.whl",
         "wheel": "wheel-0.37.1-py2.py3-none-any.whl",
     },
     "3.7": {
-        "pip": "pip-22.0.4-py3-none-any.whl",
-        "setuptools": "setuptools-60.10.0-py3-none-any.whl",
+        "pip": "pip-22.2-py3-none-any.whl",
+        "setuptools": "setuptools-63.2.0-py3-none-any.whl",
         "wheel": "wheel-0.37.1-py2.py3-none-any.whl",
     },
     "3.6": {
@@ -54,9 +53,9 @@ def get_embed_wheel(distribution, for_py_version):
     return Wheel.from_path(path)
 
 
-__all__ = (
+__all__ = [
     "get_embed_wheel",
     "BUNDLE_SUPPORT",
     "MAX",
     "BUNDLE_FOLDER",
-)
+]
